---
navigation_title: "Value count"
mapped_pages:
  - https://www.elastic.co/guide/en/elasticsearch/reference/current/search-aggregations-metrics-valuecount-aggregation.html
---

# Value count aggregation [search-aggregations-metrics-valuecount-aggregation]


A `single-value` metrics aggregation that counts the number of values that are extracted from the aggregated documents. These values can be extracted either from specific fields in the documents, or be generated by a provided script. Typically, this aggregator will be used in conjunction with other single-value aggregations. For example, when computing the `avg` one might be interested in the number of values the average is computed over.

`value_count` does not de-duplicate values, so even if a field has duplicates each value will be counted individually.

```console
POST /sales/_search?size=0
{
  "aggs" : {
    "types_count" : { "value_count" : { "field" : "type" } }
  }
}
```

Response:

```console-result
{
  ...
  "aggregations": {
    "types_count": {
      "value": 7
    }
  }
}
```

The name of the aggregation (`types_count` above) also serves as the key by which the aggregation result can be retrieved from the returned response.

## Script [_script_16]

If you need to count something more complex than the values in a single field you should run the aggregation on a [runtime field](docs-content://manage-data/data-store/mapping/runtime-fields.md).

```console
POST /sales/_search
{
  "size": 0,
  "runtime_mappings": {
    "tags": {
      "type": "keyword",
      "script": """
        emit(doc['type'].value);
        if (doc['promoted'].value) {
          emit('hot');
        }
      """
    }
  },
  "aggs": {
    "tags_count": {
      "value_count": {
        "field": "tags"
      }
    }
  }
}
```


## Histogram fields [search-aggregations-metrics-valuecount-aggregation-histogram-fields]

When the `value_count` aggregation is computed on [histogram fields](/reference/elasticsearch/mapping-reference/histogram.md), the result of the aggregation is the sum of all numbers in the `counts` array of the histogram.

For example, for the following index that stores pre-aggregated histograms with latency metrics for different networks:

```console
PUT metrics_index/_doc/1
{
  "network.name" : "net-1",
  "latency_histo" : {
      "values" : [0.1, 0.2, 0.3, 0.4, 0.5],
      "counts" : [3, 7, 23, 12, 6] <1>
   }
}

PUT metrics_index/_doc/2
{
  "network.name" : "net-2",
  "latency_histo" : {
      "values" :  [0.1, 0.2, 0.3, 0.4, 0.5],
      "counts" : [8, 17, 8, 7, 6] <1>
   }
}

POST /metrics_index/_search?size=0
{
  "aggs": {
    "total_requests": {
      "value_count": { "field": "latency_histo" }
    }
  }
}
```

1. For each histogram field the `value_count` aggregation will sum all numbers in the `counts` array.

Eventually, the aggregation will add all values for all histograms and return the following result:

```console-result
{
  ...
  "aggregations": {
    "total_requests": {
      "value": 97
    }
  }
}
```


